% Auto-generated chapter 37 for abudawud
% Hadiths in this chapter: 39

\hadithdefcmd{abudawud}{4240}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمًا فَمَا تَرَكَ شَيْئًا يَكُونُ فِي مَقَامِهِ ذَلِكَ إِلَى قِيَامِ السَّاعَةِ إِلاَّ حَدَّثَهُ حَفِظَهُ مَنْ حَفِظَهُ وَنَسِيَهُ مَنْ نَسِيَهُ قَدْ عَلِمَهُ أَصْحَابُهُ هَؤُلاَءِ وَإِنَّهُ لَيَكُونُ مِنْهُ الشَّىْءُ فَأَذْكُرُهُ كَمَا يَذْكُرُ الرَّجُلُ وَجْهَ الرَّجُلِ إِذَا غَابَ عَنْهُ ثُمَّ إِذَا رَآهُ عَرَفَهُ ‏.‏\hadithno{4240}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6604) Sahih Muslim (2891)}\hadithtrans{Narrated Hudhaifa:The Messenger of Allah (ﷺ) stood among us (to give us an address) and he left out nothing that would happen up to the last hour without telling of it. Some remembered it and some forgot, and these Companions of his have known it. When something of it which I have forgotten happens, I remembered it, just as a man remembers another's face when he is a away and recognizes him when he sees him}}
\hadithdefcmd{abudawud}{4241}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ بَدْرِ بْنِ عُثْمَانَ، عَنْ عَامِرٍ، عَنْ رَجُلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَكُونُ فِي هَذِهِ الأُمَّةِ أَرْبَعُ فِتَنٍ فِي آخِرِهَا الْفَنَاءُ ‏"‏ ‏.‏\hadithno{4241}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: four (majestic) trials (fitnahs) will take place among this community, and in their end there will be destruction}}
\hadithdefcmd{abudawud}{4242}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدٍ الْحِمْصِيُّ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَالِمٍ، حَدَّثَنِي الْعَلاَءُ بْنُ عُتْبَةَ، عَنْ عُمَيْرِ بْنِ هَانِئٍ الْعَنْسِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ كُنَّا قُعُودًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْفِتَنَ فَأَكْثَرَ فِي ذِكْرِهَا حَتَّى ذَكَرَ فِتْنَةَ الأَحْلاَسِ فَقَالَ قَائِلٌ يَا رَسُولَ اللَّهِ وَمَا فِتْنَةُ الأَحْلاَسِ قَالَ ‏ "‏ هِيَ هَرَبٌ وَحَرْبٌ ثُمَّ فِتْنَةُ السَّرَّاءِ دَخَنُهَا مِنْ تَحْتِ قَدَمَىْ رَجُلٍ مِنْ أَهْلِ بَيْتِي يَزْعُمُ أَنَّهُ مِنِّي وَلَيْسَ مِنِّي وَإِنَّمَا أَوْلِيَائِيَ الْمُتَّقُونَ ثُمَّ يَصْطَلِحُ النَّاسُ عَلَى رَجُلٍ كَوَرِكٍ عَلَى ضِلَعٍ ثُمَّ فِتْنَةُ الدُّهَيْمَاءِ لاَ تَدَعُ أَحَدًا مِنْ هَذِهِ الأُمَّةِ إِلاَّ لَطَمَتْهُ لَطْمَةً فَإِذَا قِيلَ انْقَضَتْ تَمَادَتْ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا حَتَّى يَصِيرَ النَّاسُ إِلَى فُسْطَاطَيْنِ فُسْطَاطِ إِيمَانٍ لاَ نِفَاقَ فِيهِ وَفُسْطَاطِ نِفَاقٍ لاَ إِيمَانَ فِيهِ فَإِذَا كَانَ ذَاكُمْ فَانْتَظِرُوا الدَّجَّالَ مِنْ يَوْمِهِ أَوْ مِنْ غَدِهِ ‏"‏ ‏.‏\hadithno{4242}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: When we were sitting with the Messenger of Allah (ﷺ), he talked about periods of trial (fitnahs), mentioning many of them. When he mentioned the one when people should stay in their houses, some asked him: Messenger of Allah, what is the trial (fitnah) of staying at home? He replied: It will be flight and plunder. Then will come a test which is pleasant. Its murkiness is due to the fact that it is produced by a man from the people of my house, who will assert that he belongs to me, whereas he does not, for my friends are only the God-fearing. Then the people will unite under a man who will be like a hip-bone on a rib. Then there will be the little black trial which will leave none of this community without giving him a slap, and when people say that it is finished, it will be extended. During it a man will be a believer in the morning and an infidel in the evening, so that the people will be in two camps: the camp of faith which will contain no hypocrisy, and the camp of hypocrisy which will contain no faith. When that happens, expect the Antichrist (Dajjal) that day or the next}}
\hadithdefcmd{abudawud}{4243}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا ابْنُ فَرُّوخَ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَخْبَرَنِي ابْنٌ لِقَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أَبِيهِ، قَالَ قَالَ حُذَيْفَةُ بْنُ الْيَمَانِ وَاللَّهِ مَا أَدْرِي أَنَسِيَ أَصْحَابِي أَمْ تَنَاسَوْا وَاللَّهِ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قَائِدِ فِتْنَةٍ إِلَى أَنْ تَنْقَضِيَ الدُّنْيَا يَبْلُغُ مَنْ مَعَهُ ثَلاَثَمِائَةٍ فَصَاعِدًا إِلاَّ قَدْ سَمَّاهُ لَنَا بِاسْمِهِ وَاسْمِ أَبِيهِ وَاسْمِ قَبِيلَتِهِ ‏.‏\hadithno{4243}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hudhayfah ibn al-Yaman: I swear by Allah, I do not know whether my companions have forgotten or have pretended to forgot. I swear by Allah that the Messenger of Allah (ﷺ) did not omit a leader of a wrong belief (fitnah)--up to the end of the world--whose followers reach the number of three hundred and upwards but he mentioned to us his name, his father's name and the name of his tribe}}
\hadithdefcmd{abudawud}{4244}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ سُبَيْعِ بْنِ خَالِدٍ، قَالَ أَتَيْتُ الْكُوفَةَ فِي زَمَنِ فُتِحَتْ تُسْتَرُ أَجْلُبُ مِنْهَا بِغَالاً فَدَخَلْتُ الْمَسْجِدَ فَإِذَا صَدْعٌ مِنَ الرِّجَالِ وَإِذَا رَجُلٌ جَالِسٌ تَعْرِفُ إِذَا رَأَيْتَهُ أَنَّهُ مِنْ رِجَالِ أَهْلِ الْحِجَازِ قَالَ قُلْتُ مَنْ هَذَا فَتَجَهَّمَنِي الْقَوْمُ وَقَالُوا أَمَا تَعْرِفُ هَذَا هَذَا حُذَيْفَةُ بْنُ الْيَمَانِ صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ حُذَيْفَةُ إِنَّ النَّاسَ كَانُوا يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْخَيْرِ وَكُنْتُ أَسْأَلُهُ عَنِ الشَّرِّ فَأَحْدَقَهُ الْقَوْمُ بِأَبْصَارِهِمْ فَقَالَ إِنِّي قَدْ أَرَى الَّذِي تُنْكِرُونَ إِنِّي قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ هَذَا الْخَيْرَ الَّذِي أَعْطَانَا اللَّهُ أَيَكُونُ بَعْدَهُ شَرٌّ كَمَا كَانَ قَبْلَهُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ فَمَا الْعِصْمَةُ مِنْ ذَلِكَ قَالَ ‏"‏ السَّيْفُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ثُمَّ مَاذَا يَكُونُ قَالَ ‏"‏ إِنْ كَانَ لِلَّهِ خَلِيفَةٌ فِي الأَرْضِ فَضَرَبَ ظَهْرَكَ وَأَخَذَ مَالَكَ فَأَطِعْهُ وَإِلاَّ فَمُتْ وَأَنْتَ عَاضٌّ بِجِذْلِ شَجَرَةٍ ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَاذَا قَالَ ‏"‏ ثُمَّ يَخْرُجُ الدَّجَّالُ مَعَهُ نَهْرٌ وَنَارٌ فَمَنْ وَقَعَ فِي نَارِهِ وَجَبَ أَجْرُهُ وَحُطَّ وِزْرُهُ وَمَنْ وَقَعَ فِي نَهْرِهِ وَجَبَ وِزْرُهُ وَحُطَّ أَجْرُهُ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ مَاذَا قَالَ ‏"‏ ثُمَّ هِيَ قِيَامُ السَّاعَةِ ‏"‏ ‏.‏\hadithno{4244}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hudhayfah ibn al-Yaman: Subay' ibn Khalid said: I came to Kufah at the time when Tustar was conquered. I took some mules from it. When I entered the mosque (of Kufah), I found there some people of moderate stature, and among them was a man whom you could recognize when you saw him that he was from the people of Hijaz. I asked: Who is he? The people frowned at me and said: Do you not recognize him? This is Hudhayfah ibn al-Yaman, the companion of the Messenger of Allah (ﷺ). Then Hudhayfah said: People used to ask the Messenger of Allah (ﷺ) about good, and I used to ask him about evil. Then the people stared hard at him. He said: I know the reason why you dislike it. I then asked: Messenger of Allah, will there be evil as there was before, after this good which Allah has bestowed on us? He replied: Yes. I asked: Wherein does the protection from it lie? He replied: In the sword. I asked: Messenger of Allah, what will then happen? He replied: If Allah has on Earth a caliph who flays your back and takes your property, obey him, otherwise die holding onto the stump of a tree. I asked: What will come next? He replied: Then the Antichrist (Dajjal) will come forth accompanied by a river and fire. He who falls into his fire will certainly receive his reward, and have his load taken off him, but he who falls into his river will have his load retained and his reward taken off him. I then asked: What will come next? He said: The Last Hour will come}}
\hadithdefcmd{abudawud}{4245}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ خَالِدِ بْنِ خَالِدٍ الْيَشْكُرِيِّ، بِهَذَا الْحَدِيثِ قَالَ قُلْتُ بَعْدَ السَّيْفِ قَالَ ‏"‏ بَقِيَّةٌ عَلَى أَقْذَاءٍ وَهُدْنَةٌ عَلَى دَخَنٍ ‏"‏ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ قَالَ كَانَ قَتَادَةُ يَضَعُهُ عَلَى الرِّدَّةِ الَّتِي فِي زَمَنِ أَبِي بَكْرٍ ‏"‏ عَلَى أَقْذَاءٍ ‏"‏ ‏.‏ يَقُولُ قَذَى ‏.‏ ‏"‏ وَهُدْنَةٌ ‏"‏ ‏.‏ يَقُولُ صُلْحٌ ‏"‏ عَلَى دَخَنٍ ‏"‏ ‏.‏ عَلَى ضَغَائِنَ ‏.‏\hadithno{4245}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The traditions mentioned above has also been transmitted by Khalid b. Khalid al-Yashkuri through different chain of narrators. This version has:I (Hudhaifah) asked : Will any be spared after the use of the sword ? He replied: There will be remnant with specks in its eye and an illusory truce. He then transmitted the rest of the tradition. Qatadah applied this to the apostasy during the Caliphate of Abu Bakr. The word aqdha' (sing. qadhan) means specks, hudnah means truce and dakhan means malice}}
\hadithdefcmd{abudawud}{4246}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - عَنْ حُمَيْدٍ، عَنْ نَصْرِ بْنِ عَاصِمٍ اللَّيْثِيِّ، قَالَ أَتَيْنَا الْيَشْكُرِيَّ فِي رَهْطٍ مِنْ بَنِي لَيْثٍ فَقَالَ مَنِ الْقَوْمُ فَقُلْنَا بَنُو لَيْثٍ أَتَيْنَاكَ نَسْأَلُكَ عَنْ حَدِيثِ حُذَيْفَةَ فَذَكَرَ الْحَدِيثَ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ بَعْدَ هَذَا الْخَيْرِ شَرٌّ قَالَ ‏"‏ فِتْنَةٌ وَشَرٌّ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ بَعْدَ هَذَا الشَّرِّ خَيْرٌ قَالَ ‏"‏ يَا حُذَيْفَةُ تَعَلَّمْ كِتَابَ اللَّهِ وَاتَّبِعْ مَا فِيهِ ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ بَعْدَ هَذَا الشَّرِّ خَيْرٌ قَالَ ‏"‏ هُدْنَةٌ عَلَى دَخَنٍ وَجَمَاعَةٌ عَلَى أَقْذَاءٍ فِيهَا أَوْ فِيهِمْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ الْهُدْنَةُ عَلَى الدَّخَنِ مَا هِيَ قَالَ ‏"‏ لاَ تَرْجِعُ قُلُوبُ أَقْوَامٍ عَلَى الَّذِي كَانَتْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَبَعْدَ هَذَا الْخَيْرِ شَرٌّ قَالَ ‏"‏ فِتْنَةٌ عَمْيَاءُ صَمَّاءُ عَلَيْهَا دُعَاةٌ عَلَى أَبْوَابِ النَّارِ فَإِنْ تَمُتْ يَا حُذَيْفَةُ وَأَنْتَ عَاضٌّ عَلَى جِذْلٍ خَيْرٌ لَكَ مِنْ أَنْ تَتَّبِعَ أَحَدًا مِنْهُمْ ‏"‏ ‏.‏\hadithno{4246}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hudhayfah: The tradition mentioned above (No. 4232) has also been transmitted through a different chain of narrators by Nasr ibn Asim al-Laythi who said: We came to al-Yashkuri with a group of the people of Banu Layth. He asked: Who are these people? We replied: Banu Layth. We have come to you to ask you about the tradition of Hudhayfah. He then mentioned the tradition and said: I asked: Messenger of Allah, will there be evil after this good? He replied: There will be trial (fitnah) and evil. I asked: Messenger of Allah, will there be good after this evil? He replied: Learn the Book of Allah, Hudhayfah, and adhere to its contents. He said it three times. I asked: Messenger of Allah, will there be good after this evil? He replied: An illusory truce and a community with specks in its eye. I asked: Messenger of Allah, what do you mean by an illusory community? He replied: The hearts of the people will not return to their former condition. I asked: Messenger of Allah, will there be evil after this good? He replied: There will be wrong belief which will blind and deafen men to the truth in which there will be summoners at the gates of Hell. If you, Hudhayfah, die adhering to a stump, it will be better for you than following any of them}}
\hadithdefcmd{abudawud}{4247}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَبُو التَّيَّاحِ، عَنْ صَخْرِ بْنِ بَدْرٍ الْعِجْلِيِّ، عَنْ سُبَيْعِ بْنِ خَالِدٍ، بِهَذَا الْحَدِيثِ عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَإِنْ لَمْ تَجِدْ يَوْمَئِذٍ خَلِيفَةً فَاهْرَبْ حَتَّى تَمُوتَ فَإِنْ تَمُتْ وَأَنْتَ عَاضٌّ ‏"‏ ‏.‏ وَقَالَ فِي آخِرِهِ قَالَ قُلْتُ فَمَا يَكُونُ بَعْدَ ذَلِكَ قَالَ ‏"‏ لَوْ أَنَّ رَجُلاً نَتَجَ فَرَسًا لَمْ تُنْتَجْ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{4247}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Hudhaifah through a different chain of narrators from the Prophet (ﷺ). This version says:He said: If you do not find a caliph in those days, then flee away until you die, even of you die holding on (to a stump of a tree). I asked: What will come next ? He replied: If a man wants the mare to bring forth a foal, it will not deliver in till the Last Hour comes}}
\hadithdefcmd{abudawud}{4248}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ رَبِّ الْكَعْبَةِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَايَعَ إِمَامًا فَأَعْطَاهُ صَفْقَةَ يَدِهِ وَثَمَرَةَ قَلْبِهِ فَلْيُطِعْهُ مَا اسْتَطَاعَ فَإِنْ جَاءَ آخَرُ يُنَازِعُهُ فَاضْرِبُوا رَقَبَةَ الآخَرِ ‏"‏ ‏.‏ قُلْتُ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏ قُلْتُ هَذَا ابْنُ عَمِّكَ مُعَاوِيَةُ يَأْمُرُنَا أَنْ نَفْعَلَ وَنَفْعَلَ ‏.‏ قَالَ أَطِعْهُ فِي طَاعَةِ اللَّهِ وَاعْصِهِ فِي مَعْصِيَةِ اللَّهِ ‏.‏\hadithno{4248}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1844)}\hadithtrans{Narrated Abdullah b. 'Amr:The Prophet (ﷺ) as saying: If a man takes an oath of allegiance to a leader, and puts his hand on his hand and does it with the sincerity of his heart, he should obey him as much as possible. If another man comes and contests him, then behead the other one. The narrator 'Abd al-Rahman said: I asked: Have you heard this from the Messenger of Allah ? He said: My ears heard it and my heart retained it. I said: Your cousin Mu'awiyah orders us that we should do this and do that. He replied: Obey him in the acts of obedience to Allah, and disobey him in the acts of disobedience to Allah}}
\hadithdefcmd{abudawud}{4249}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ أَفْلَحَ مَنْ كَفَّ يَدَهُ ‏"‏ ‏.‏\hadithno{4249}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) as saying: Woe to Arabs because of evil which has drawn near! He will escape who restrains his hand}}
\hadithdefcmd{abudawud}{4250}{قَالَ أَبُو دَاوُدَ حُدِّثْتُ عَنِ ابْنِ وَهْبٍ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْمُسْلِمُونَ أَنْ يُحَاصَرُوا إِلَى الْمَدِينَةِ حَتَّى يَكُونَ أَبْعَدُ مَسَالِحِهِمْ سَلاَحَ ‏"‏ ‏.‏\hadithno{4250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dawud said:Ibn 'Umar reported the Messenger of Allah (ﷺ) as saying: The Muslims will soon be besieged up to Medina, so that their most distant frontier outpost will be Salah}}
\hadithdefcmd{abudawud}{4251}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، عَنْ عَنْبَسَةَ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ وَسَلاَحُ قَرِيبٌ مِنْ خَيْبَرَ ‏.‏\hadithno{4251}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{Al-Zuhri said:Salah is near Khaibar}}
\hadithdefcmd{abudawud}{4252}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ زَوَى لِيَ الأَرْضَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ إِنَّ رَبِّي زَوَى لِيَ الأَرْضَ فَرَأَيْتُ مَشَارِقَهَا وَمَغَارِبَهَا وَإِنَّ مُلْكَ أُمَّتِي سَيَبْلُغُ مَا زُوِيَ لِي مِنْهَا وَأُعْطِيتُ الْكَنْزَيْنِ الأَحْمَرَ وَالأَبْيَضَ وَإِنِّي سَأَلْتُ رَبِّي لأُمَّتِي أَنْ لاَ يُهْلِكَهَا بِسَنَةٍ بِعَامَّةٍ وَلاَ يُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ فَيَسْتَبِيحَ بَيْضَتَهُمْ وَإِنَّ رَبِّي قَالَ لِي يَا مُحَمَّدُ إِنِّي إِذَا قَضَيْتُ قَضَاءً فَإِنَّهُ لاَ يُرَدُّ وَلاَ أُهْلِكُهُمْ بِسَنَةٍ بِعَامَّةٍ وَلاَ أُسَلِّطُ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ فَيَسْتَبِيحَ بَيْضَتَهُمْ وَلَوِ اجْتَمَعَ عَلَيْهِمْ مَنْ بَيْنَ أَقْطَارِهَا أَوْ قَالَ بِأَقْطَارِهَا حَتَّى يَكُونَ بَعْضُهُمْ يُهْلِكُ بَعْضًا وَحَتَّى يَكُونَ بَعْضُهُمْ يَسْبِي بَعْضًا وَإِنَّمَا أَخَافُ عَلَى أُمَّتِي الأَئِمَّةَ الْمُضِلِّينَ وَإِذَا وُضِعَ السَّيْفُ فِي أُمَّتِي لَمْ يُرْفَعْ عَنْهَا إِلَى يَوْمِ الْقِيَامَةِ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تَلْحَقَ قَبَائِلُ مِنْ أُمَّتِي بِالْمُشْرِكِينَ وَحَتَّى تَعْبُدَ قَبَائِلُ مِنْ أُمَّتِي الأَوْثَانَ وَإِنَّهُ سَيَكُونُ فِي أُمَّتِي كَذَّابُونَ ثَلاَثُونَ كُلُّهُمْ يَزْعُمُ أَنَّهُ نَبِيٌّ وَأَنَا خَاتَمُ النَّبِيِّينَ لاَ نَبِيَّ بَعْدِي وَلاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي عَلَى الْحَقِّ ‏"‏ ‏.‏ قَالَ ابْنُ عِيسَى ‏"‏ ظَاهِرِينَ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا ‏"‏ لاَ يَضُرُّهُمْ مَنْ خَالَفَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ ‏"‏ ‏.‏\hadithno{4252}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2889)}\hadithtrans{Narrated Thawban:The Messenger of Allah (ﷺ) as saying: Allah, the Exalted, folded for me the earth, or he said (the narrator is doubtful): My Lord folded for me the earth, so much so that I saw its easts and wests (i.e. the extremities). The kingdom of my community will reach as far as the earth was floded for me. The two treasures, the red and the white, were bestowed on me. I prayed to my Lord that He may not destroy my community by prevailing famine, and not give their control to an enemy who annihilates then en masse except from among themselves. My Lord said to me: Muhammad, If I make a decision, it is not withdrawn ; and I shall not destroy them by prevailing famine, and I shall not give their control to an enemy, except from among themselves, who exterminates them en masse, even if they are stormed from all sides of the earth ; only a section of them will destroy another section, and a section will captive another section. I am afraid about my community of those leaders who will lead astray. When the sword is used among my people, it will not be withdrawn from them till the Day of Resurrection, and the Last Hour will not come before the tribes of my people attach themselves to the polytheists and tribes of my people worship idols. There will be among my people thirty great liars each of them asserting that he is (Allah's) prophet, where as I am the seal of the Prophet s after whom (me) there will be no prophet ; and a section of my people will continue to hold to the truth - (according to the Ibn Isa's version: (will continue to dominate) - the agreed version goes: "and will not be injured by those who oppose them, till Allah's command comes}}
\hadithdefcmd{abudawud}{4253}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنِي أَبِي، - قَالَ ابْنُ عَوْفٍ وَقَرَأْتُ فِي أَصْلِ إِسْمَاعِيلَ - قَالَ حَدَّثَنِي ضَمْضَمٌ، عَنْ شُرَيْحٍ، عَنْ أَبِي مَالِكٍ، - يَعْنِي الأَشْعَرِيَّ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ أَجَارَكُمْ مِنْ ثَلاَثِ خِلاَلٍ أَنْ لاَ يَدْعُوَ عَلَيْكُمْ نَبِيُّكُمْ فَتَهْلِكُوا جَمِيعًا وَأَنْ لاَ يَظْهَرَ أَهْلُ الْبَاطِلِ عَلَى أَهْلِ الْحَقِّ وَأَنْ لاَ تَجْتَمِعُوا عَلَى ضَلاَلَةٍ ‏"‏ ‏.‏\hadithno{4253}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMalik al-Ash'ari: The Prophet (ﷺ) said: Allah has protected you from three things: that your Prophet should not invoke a curse on you and should all perish, that those who follow what is false should not prevail over those who follow the truth, and that you should not all agree in an error}}
\hadithdefcmd{abudawud}{4254}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنِ الْبَرَاءِ بْنِ نَاجِيَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ تَدُورُ رَحَى الإِسْلاَمِ لِخَمْسٍ وَثَلاَثِينَ أَوْ سِتٍّ وَثَلاَثِينَ أَوْ سَبْعٍ وَثَلاَثِينَ فَإِنْ يَهْلِكُوا فَسَبِيلُ مَنْ هَلَكَ وَإِنْ يَقُمْ لَهُمْ دِينُهُمْ يَقُمْ لَهُمْ سَبْعِينَ عَامًا ‏"‏ ‏.‏ قَالَ قُلْتُ أَمِمَّا بَقِيَ أَوْ مِمَّا مَضَى قَالَ ‏"‏ مِمَّا مَضَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ مَنْ قَالَ خِرَاشٍ فَقَدْ أَخْطَأَ ‏.‏\hadithno{4254}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: The mill of Islam will go round till the year thirty-five, or thirty-six, or thirty-seven; then if they perish, they will have followed the path of those who perished before them, but if their religion is maintained, it will be maintained for seventy years. I asked: Does it mean seventy years which remain or seventy years which are gone by? He replied: It means (seventy years) that are gone by. Abu Dawud said: Those who recorded Khirash, the name of a narrator, are wrong. (The correct name is Hirash)}}
\hadithdefcmd{abudawud}{4255}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَتَقَارَبُ الزَّمَانُ وَيَنْقُصُ الْعِلْمُ وَتَظْهَرُ الْفِتَنُ وَيُلْقَى الشُّحُّ وَيَكْثُرُ الْهَرْجُ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ أَيَّةُ هُوَ قَالَ ‏"‏ الْقَتْلُ الْقَتْلُ ‏"‏ ‏.‏\hadithno{4255}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (157 After 2672)}\hadithtrans{Narrated Abu Hurairah :The Messenger of Allah (ﷺ) as saying: The time will become short, knowledge will be decreased, civil strife (fitan) will appear, niggardliness will be case into people's heart, and harj will be prevalent. He was asked: Messenger of Allah! what is it: He replied: Slaughter, slaughter}}
\hadithdefcmd{abudawud}{4256}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عُثْمَانَ الشَّحَّامِ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ فِتْنَةٌ يَكُونُ الْمُضْطَجِعُ فِيهَا خَيْرًا مِنَ الْجَالِسِ وَالْجَالِسُ خَيْرًا مِنَ الْقَائِمِ وَالْقَائِمُ خَيْرًا مِنَ الْمَاشِي وَالْمَاشِي خَيْرًا مِنَ السَّاعِي ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَا تَأْمُرُنِي قَالَ ‏"‏ مَنْ كَانَتْ لَهُ إِبِلٌ فَلْيَلْحَقْ بِإِبِلِهِ وَمَنْ كَانَتْ لَهُ غَنَمٌ فَلْيَلْحَقْ بِغَنَمِهِ وَمَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَلْحَقْ بِأَرْضِهِ ‏"‏ ‏.‏ قَالَ فَمَنْ لَمْ يَكُنْ لَهُ شَىْءٌ مِنْ ذَلِكَ قَالَ ‏"‏ فَلْيَعْمِدْ إِلَى سَيْفِهِ فَلْيَضْرِبْ بِحَدِّهِ عَلَى حَرَّةٍ ثُمَّ لِيَنْجُ مَا اسْتَطَاعَ النَّجَاءَ ‏"‏ ‏.‏\hadithno{4256}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2887)}\hadithtrans{Narrated AbuBakrah: The Messenger of Allah (ﷺ) said: There will be a period of commotion in which the one who lies down will be better than the one who sits, and the one who sits is better than the one who stands, and the one who stands is better than the one who walks, and the one who walks is better than the one who runs (to it). He asked: What do you command me to do, Messenger of Allah? He replied: He who has camels should remain with his camels, he who has sheep should remain with his sheep, and he who has land should remain with his land. He asked: If anyone has more of these, (what should he do)? He replied: He should take his sword, strike its edge on a stone, and then escape if he can}}
\hadithdefcmd{abudawud}{4257}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، حَدَّثَنَا مُفَضَّلٌ، عَنْ عَيَّاشٍ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ حُسَيْنِ بْنِ عَبْدِ الرَّحْمَنِ الأَشْجَعِيِّ، أَنَّهُ سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْحَدِيثِ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ دَخَلَ عَلَىَّ بَيْتِي وَبَسَطَ يَدَهُ لِيَقْتُلَنِي قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُنْ كَابْنَىْ آدَمَ ‏"‏ ‏.‏ وَتَلاَ يَزِيدُ ‏\{‏ لَئِنْ بَسَطْتَ إِلَىَّ يَدَكَ ‏\}‏ الآيَةَ ‏.‏\hadithno{4257}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: I asked: Messenger of Allah! tell me if someone enters my house and extends his hands to kill me (what should I do?) The Messenger of Allah (ﷺ) replied: Be like the two sons of Adam. The narrator Yazid (ibn Khalid) then recited the verse: "If thou dost stretch they hand against me to slay me." [5:]}}
\hadithdefcmd{abudawud}{4258}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا أَبِي، حَدَّثَنَا شِهَابُ بْنُ خِرَاشٍ، عَنِ الْقَاسِمِ بْنِ غَزْوَانَ، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ الْجَزَرِيِّ، عَنْ سَالِمٍ، حَدَّثَنِي عَمْرُو بْنُ وَابِصَةَ الأَسَدِيُّ، عَنْ أَبِيهِ، وَابِصَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فَذَكَرَ بَعْضَ حَدِيثِ أَبِي بَكْرَةَ قَالَ ‏ "‏ قَتْلاَهَا كُلُّهُمْ فِي النَّارِ ‏"‏ ‏.‏ قَالَ فِيهِ قُلْتُ مَتَى ذَلِكَ يَا ابْنَ مَسْعُودٍ قَالَ تِلْكَ أَيَّامُ الْهَرْجِ حَيْثُ لاَ يَأْمَنُ الرَّجُلُ جَلِيسَهُ ‏.‏ قُلْتُ فَمَا تَأْمُرُنِي إِنْ أَدْرَكَنِي ذَلِكَ الزَّمَانُ قَالَ تَكُفُّ لِسَانَكَ وَيَدَكَ وَتَكُونُ حِلْسًا مِنْ أَحْلاَسِ بَيْتِكَ ‏.‏ فَلَمَّا قُتِلَ عُثْمَانُ طَارَ قَلْبِي مَطَارَهُ فَرَكِبْتُ حَتَّى أَتَيْتُ دِمَشْقَ فَلَقِيتُ خُرَيْمَ بْنَ فَاتِكٍ فَحَدَّثْتُهُ فَحَلَفَ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَسَمِعَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا حَدَّثَنِيهِ ابْنُ مَسْعُودٍ ‏.‏\hadithno{4258}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud ; Khuraym ibn Fatik: The tradition mentioned above (No. 4243) has also been transmitted by Ibn Mas'ud through a different chain of narrators. Ibn Mas'ud said: I heard the Prophet (ﷺ) say: He then mentioned a portion of the tradition narrated by AbuBakrah (No. 4243). This version adds: He (the Prophet) said: All their slain will go to Hell. I (Wabisah) asked: When will this happen Ibn Mas'ud? He replied: This is the period of turmoil (harj) when a man will not be safe from his associates. I asked: What do you command me (to do) if I happen to live during that period? He replied: You should restrain your tongue and hand and stay at home. When Uthman was slain, I recollected this tradition. I then rode (on a camel) and came to Damascus. There I met Khuraym ibn Fatik and mentioned this tradition to him. He swore by Allah, there was no god but He, he had heard it from the Messenger of Allah (ﷺ), as Ibn Mas'ud transmitted it to me (Wabisah)}}
\hadithdefcmd{abudawud}{4259}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَرْوَانَ، عَنْ هُزَيْلٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ فِتَنًا كَقِطَعِ اللَّيْلِ الْمُظْلِمِ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي فَكَسِّرُوا قِسِيَّكُمْ وَقَطِّعُوا أَوْتَارَكُمْ وَاضْرِبُوا سُيُوفَكُمْ بِالْحِجَارَةِ فَإِنْ دُخِلَ - يَعْنِي عَلَى أَحَدٍ مِنْكُمْ - فَلْيَكُنْ كَخَيْرِ ابْنَىْ آدَمَ ‏"‏ ‏.‏\hadithno{4259}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Messenger of Allah (ﷺ) said: Before the Last Hour there will be commotions like pieces of a dark night in which a man will be a believer in the morning and an infidel in the evening, or a believer in the evening and infidel in the morning. He who sits during them will be better than he who gets up and he who walks during them is better than he who runs. So break your bows, cut your bowstrings and strike your swords on stones. If people then come in to one of you, let him be like the better of Adam's two sons}}
\hadithdefcmd{abudawud}{4260}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ رَقَبَةَ بْنِ مَصْقَلَةَ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ سَمُرَةَ - قَالَ كُنْتُ آخِذًا بِيَدِ ابْنِ عُمَرَ فِي طَرِيقٍ مِنْ طُرُقِ الْمَدِينَةِ إِذْ أَتَى عَلَى رَأْسٍ مَنْصُوبٍ فَقَالَ شَقِيَ قَاتِلُ هَذَا ‏.‏ فَلَمَّا مَضَى قَالَ وَمَا أَرَى هَذَا إِلاَّ قَدْ شَقِيَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ مَشَى إِلَى رَجُلٍ مِنْ أُمَّتِي لِيَقْتُلَهُ فَلْيَقُلْ هَكَذَا فَالْقَاتِلُ فِي النَّارِ وَالْمَقْتُولُ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الثَّوْرِيُّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُمَيْرٍ أَوْ سُمَيْرَةَ وَرَوَاهُ لَيْثُ بْنُ أَبِي سُلَيْمٍ عَنْ عَوْنٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُمَيْرَةَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ لِي الْحَسَنُ بْنُ عَلِيٍّ حَدَّثَنَا أَبُو الْوَلِيدِ - يَعْنِي بِهَذَا الْحَدِيثِ - عَنْ أَبِي عَوَانَةَ وَقَالَ هُوَ فِي كِتَابِي ابْنُ سَبْرَةَ وَقَالُوا سَمُرَةَ وَقَالُوا سُمَيْرَةَ هَذَا كَلاَمُ أَبِي الْوَلِيدِ ‏.‏\hadithno{4260}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: AbdurRahman ibn Samurah said: I was holding the hand of Ibn Umar on one of the ways of Medina. He suddenly came to a hanging head. He said: Unhappy is the one who killed him. When he proceeded, he said: I do not consider him but unfortunate. I heard the Messenger of Allah (ﷺ) say: If anyone goes to a man of my community in order to kill him, he should say in this way, the one who kills will go to Hell and the one who is killed will go to Paradise. Abu Dawud said: Al-Thawri has transmitted it from 'Awn from 'Abd al-Rahman b. Sumair or Sumairah ; and Laith b. Abu Sulaim transmitted it from 'Awn from 'Abd al-Rahman b. Sumairah. Abu Dawud said: Al-Hasan b. 'Ali said to me: Abu al-Walid transmitted this tradition to us from Abu 'Awanah, and said: It (the name Ibn Samurah) is in my notebook Ibn Sabrah. The people also transmitted it as Samurah and Sumairah. These are wordings of Abu al-Walid}}
\hadithdefcmd{abudawud}{4261}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنِ الْمُشَعَّثِ بْنِ طَرِيفٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ وَسَعْدَيْكَ ‏.‏ فَذَكَرَ الْحَدِيثَ قَالَ فِيهِ ‏"‏ كَيْفَ أَنْتَ إِذَا أَصَابَ النَّاسَ مَوْتٌ يَكُونُ الْبَيْتُ فِيهِ بِالْوَصِيفِ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ أَوْ قَالَ مَا خَارَ اللَّهُ لِي وَرَسُولُهُ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّبْرِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ تَصْبِرُ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ وَسَعْدَيْكَ ‏.‏ قَالَ ‏"‏ كَيْفَ أَنْتَ إِذَا رَأَيْتَ أَحْجَارَ الزَّيْتِ قَدْ غَرِقَتْ بِالدَّمِ ‏"‏ ‏.‏ قُلْتُ مَا خَارَ اللَّهُ لِي وَرَسُولُهُ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِمَنْ أَنْتَ مِنْهُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ آخُذُ سَيْفِي وَأَضَعُهُ عَلَى عَاتِقِي قَالَ ‏"‏ شَارَكْتَ الْقَوْمَ إِذًا ‏"‏ ‏.‏ قُلْتُ فَمَا تَأْمُرُنِي قَالَ ‏"‏ تَلْزَمُ بَيْتَكَ ‏"‏ ‏.‏ قُلْتُ فَإِنْ دُخِلَ عَلَىَّ بَيْتِي قَالَ ‏"‏ فَإِنْ خَشِيتَ أَنْ يَبْهَرَكَ شُعَاعُ السَّيْفِ فَأَلْقِ ثَوْبَكَ عَلَى وَجْهِكَ يَبُوءُ بِإِثْمِكَ وَإِثْمِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَذْكُرِ الْمُشَعَّثَ فِي هَذَا الْحَدِيثِ غَيْرُ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{4261}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuDharr: The Messenger of Allah (ﷺ) said to me: O AbuDharr. I replied: At thy service and at thy pleasure, Messenger of Allah. He then mentioned the tradition in which he said: What will you do when there the death of the people (in Medina) and a house will reach the value of a slave (that is, a grave will be sold for a slave). I replied: Allah and His Apostle know best. Or he said: What Allah and His Apostle choose for me. He said: You must show endurance. Or he said; you may endure. He then said to me: What will you do, AbuDharr, when you see the Ahjar az-Zayt covered with blood? I replied: What Allah and His Apostle choose for me. He said: You must go to those who are like-minded. I asked: Should I not take my sword and put it on my shoulder? He replied: you would then associate yourself with the people. I then asked: What do you order me to do? You must stay at home. I asked: (What should I do) if people enter my house and find me? He replied: If you are afraid the gleam of the sword may dazzle you, put the end of your garment over your face in order that (the one who kills you) may bear the punishment of your sins and his. Abu Dawud said: No one mentioned al-Mush'ath in the chain of this tradition except Hammad b. Zaid}}
\hadithdefcmd{abudawud}{4262}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي كَبْشَةَ، قَالَ سَمِعْتُ أَبَا مُوسَى، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ بَيْنَ أَيْدِيكُمْ فِتَنًا كَقِطَعِ اللَّيْلِ الْمُظْلِمِ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي ‏"‏ ‏.‏ قَالُوا فَمَا تَأْمُرُنَا قَالَ ‏"‏ كُونُوا أَحْلاَسَ بُيُوتِكُمْ ‏"‏ ‏.‏\hadithno{4262}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Prophet (ﷺ) said: Before you there will be commotions like pieces of a dark night in which a man will be a believer in the morning and an infidel in the evening. He who sits during them will be better than he who gets up, and he who gets up during them is better than he who walks, and he who walks during them is better than he who runs. They (the people) said: What do you order us to do? He replied: Keep to your houses}}
\hadithdefcmd{abudawud}{4263}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ الْمِصِّيصِيُّ، حَدَّثَنَا حَجَّاجٌ، - يَعْنِي ابْنَ مُحَمَّدٍ - حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ جُبَيْرٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، قَالَ ايْمُ اللَّهِ لَقَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ السَّعِيدَ لَمَنْ جُنِّبَ الْفِتَنَ إِنَّ السَّعِيدَ لَمَنْ جُنِّبَ الْفِتَنَ إِنَّ السَّعِيدَ لَمَنْ جُنِّبَ الْفِتَنَ وَلَمَنِ ابْتُلِيَ فَصَبَرَ فَوَاهًا ‏"‏ ‏.‏\hadithno{4263}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Miqdad ibn al-Aswad: I swear by Allah, I heard the Messenger of Allah (ﷺ) say: The happy man is he who avoids dissensions: happy is the man who avoids dissensions; happy is the man who avoids dissensions: but how fine is the man who is afflicted and shows endurance}}
\hadithdefcmd{abudawud}{4264}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنِي اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ قَالَ خَالِدُ بْنُ أَبِي عِمْرَانَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَتَكُونُ فِتْنَةٌ صَمَّاءُ بَكْمَاءُ عَمْيَاءُ مَنْ أَشْرَفَ لَهَا اسْتَشْرَفَتْ لَهُ وَإِشْرَافُ اللِّسَانِ فِيهَا كَوُقُوعِ السَّيْفِ ‏"‏ ‏.‏\hadithno{4264}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: There will be civil strife (fitnah) which will render people deaf, dumb and blind regarding what is right. Those who contemplate it will be drawn by it, and giving rein to the tongue during it will be like smiting with the sword}}
\hadithdefcmd{abudawud}{4265}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا لَيْثٌ، عَنْ طَاوُسٍ، عَنْ رَجُلٍ، يُقَالُ لَهُ زِيَادٌ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهَا سَتَكُونُ فِتْنَةٌ تَسْتَنْظِفُ الْعَرَبَ قَتْلاَهَا فِي النَّارِ اللِّسَانُ فِيهَا أَشَدُّ مِنْ وَقْعِ السَّيْفِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الثَّوْرِيُّ عَنْ لَيْثٍ عَنْ طَاوُسٍ عَنِ الأَعْجَمِ ‏.‏\hadithno{4265}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: There will be civil strife which wipe out the Arabs, and their slain will go to Hell. During it the tongue will be more severe than blows of the sword. Abu Dawud said: Al-Thawri transmitted it from Laith, from Tawus on the authority of Al-A'jam}}
\hadithdefcmd{abudawud}{4266}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ الطَّبَّاعِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْقُدُّوسِ، قَالَ زِيَادٌ سِيمِينْ كُوشْ ‏.‏\hadithno{4266}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abd Allah b. 'Abd al-Quddus mentioned in his version:Ziyad, one who has white ears}}
\hadithdefcmd{abudawud}{4267}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ أَنْ يَكُونَ خَيْرُ مَالِ الْمُسْلِمِ غَنَمًا يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏ ‏.‏\hadithno{4267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (19)}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) as saying: A Muslim's best property will soon be sheep which he will take to the tops of the mountains and the places where the rain falls, fleeing with his religion from the civil strife (fitan)}}
\hadithdefcmd{abudawud}{4268}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، وَيُونُسَ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ خَرَجْتُ وَأَنَا أُرِيدُ، - يَعْنِي فِي الْقِتَالِ - فَلَقِيَنِي أَبُو بَكْرَةَ فَقَالَ ارْجِعْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{4268}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (31) Sahih Muslim (2888)}\hadithtrans{Ahnaf b. Qais said:I came out with the intention of (participating in) fighting. Abu Bakrah met me and said: Go back, for I heard the Messenger of Allah (ﷺ) say: When two Muslims face each other with their swords, the killer and the slain will go to Hell. He asked: Messenger of Allah, this is the killer (so naturally he should go to Hell), but what is the matter with the slain ? He replied: He intended to kill his companion}}
\hadithdefcmd{abudawud}{4269}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ الْحَسَنِ، بِإِسْنَادِهِ وَمَعْنَاهُ مُخْتَصَرًا ‏.‏ قَالَ أَبُو دَاوُدَ لِمُحَمَّدٍ - يَعْنِي ابْنَ الْمُتَوَكِّلِ - أَخٌ ضَعِيفٌ يُقَالُ لَهُ الْحُسَيْنُ ‏.‏\hadithno{4269}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2888)}\hadithtrans{The tradition mentioned above has also been transmitted briefly by al-Hasan through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4270}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنْ خَالِدِ بْنِ دِهْقَانَ، قَالَ كُنَّا فِي غَزْوَةِ الْقُسْطَنْطِينِيَّةِ بِذُلُقْيَةَ فَأَقْبَلَ رَجُلٌ مِنْ أَهْلِ فِلَسْطِينَ - مِنْ أَشْرَافِهِمْ وَخِيَارِهِمْ يَعْرِفُونَ ذَلِكَ لَهُ يُقَالُ لَهُ هَانِئُ بْنُ كُلْثُومِ بْنِ شَرِيكٍ الْكِنَانِيُّ - فَسَلَّمَ عَلَى عَبْدِ اللَّهِ بْنِ أَبِي زَكَرِيَّا وَكَانَ يَعْرِفُ لَهُ حَقَّهُ قَالَ لَنَا خَالِدٌ فَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زَكَرِيَّا قَالَ سَمِعْتُ أُمَّ الدَّرْدَاءِ تَقُولُ سَمِعْتُ أَبَا الدَّرْدَاءِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّ ذَنْبٍ عَسَى اللَّهُ أَنْ يَغْفِرَهُ إِلاَّ مَنْ مَاتَ مُشْرِكًا أَوْ مُؤْمِنٌ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا ‏"‏ ‏.‏ فَقَالَ هَانِئُ بْنُ كُلْثُومٍ سَمِعْتُ مَحْمُودَ بْنَ الرَّبِيعِ يُحَدِّثُ عَنْ عُبَادَةَ بْنِ الصَّامِتِ أَنَّهُ سَمِعَهُ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ قَتَلَ مُؤْمِنًا فَاعْتَبَطَ بِقَتْلِهِ لَمْ يَقْبَلِ اللَّهُ مِنْهُ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏ قَالَ لَنَا خَالِدٌ ثُمَّ حَدَّثَنِي ابْنُ أَبِي زَكَرِيَّا عَنْ أُمِّ الدَّرْدَاءِ عَنْ أَبِي الدَّرْدَاءِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَزَالُ الْمُؤْمِنُ مُعْنِقًا صَالِحًا مَا لَمْ يُصِبْ دَمًا حَرَامًا فَإِذَا أَصَابَ دَمًا حَرَامًا بَلَّحَ ‏"‏ ‏.‏ وَحَدَّثَ هَانِئُ بْنُ كُلْثُومٍ عَنْ مَحْمُودِ بْنِ الرَّبِيعِ عَنْ عُبَادَةَ بْنِ الصَّامِتِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَهُ سَوَاءً ‏.‏\hadithno{4270}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbudDarda' and Ubadah ibn as-Samit: Khalid ibn Dihqan said: When we were engaged in the battle of Constantinople at Dhuluqiyyah, a man of the people of Palestine, who was one of their nobility and elite and whose rank was known to them, came forward. He was called Hani ibn Kulthum ibn Sharik al-Kinani. He greeted Abdullah ibn Zakariyya who knew his rank. Khalid said to us: Abdullah ibn AbuZakariyya told us: I heard Umm ad-Darda' say: I heard AbudDarda' say: I heard the Messenger of Allah (ﷺ) say: It is hoped that Allah may forgive every sin, except in the case of one who dies a polytheist, or one who purposely kills a believer. Hani ibn Kulthum ar-Rabi' then said: I heard Mahmud ibn ar-Rabi' transmitting a tradition from Ubadah ibn as-Samit who transmitted from the Messenger of Allah (ﷺ) who said: If a man kills a believer unjustly, Allah will not accept any action or duty of his, obligatory or supererogatory. Khalid then said to us: Ibn AbuZakariyya transmitted a tradition to us from Umm ad-Darda' on the authority of AbudDarda' from the Messenger of Allah (ﷺ) who said: A believer will continue to go on quickly and well so long as he does not shed unlawful blood; when he sheds unlawful blood, he becomes slow and heavy-footed. A similar tradition has been transmitted by Hani ibn Kulthum from Mahmud ibn ar-Rabi' on the authority of Ubadah ibn as-Samit from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{4271}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو، عَنْ مُحَمَّدِ بْنِ مُبَارَكٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، أَوْ غَيْرُهُ قَالَ قَالَ خَالِدُ بْنُ دِهْقَانَ سَأَلْتُ يَحْيَى بْنَ يَحْيَى الْغَسَّانِيَّ عَنْ قَوْلِهِ ‏ "‏ اعْتَبَطَ بِقَتْلِهِ ‏"‏ ‏.‏ قَالَ الَّذِينَ يُقَاتِلُونَ فِي الْفِتْنَةِ فَيَقْتُلُ أَحَدُهُمْ فَيَرَى أَنَّهُ عَلَى هُدًى لاَ يَسْتَغْفِرُ اللَّهَ - يَعْنِي - مِنْ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ فَاعْتَبَطَ يَصُبُّ دَمَهُ صَبًّا ‏.‏\hadithno{4271}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{Khalid b. Dihqan said:I asked Yahya b. Yahya al-Ghassani about the word i'tabata bi qatlihi spoken by him (as mentioned in the previous tradition). He said: It means those people who fight during the period of commotion (fitnah), and one of them kills (the other people) presuming that he is in the right, so he does not beg pardon of Allah of that (sin). Abu Dawud said: And he said: The word fa'tabata means "he shed blood profusely}}
\hadithdefcmd{abudawud}{4272}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، عَنْ أَبِي الزِّنَادِ، عَنْ مُجَالِدِ بْنِ عَوْفٍ، أَنَّ خَارِجَةَ بْنَ زَيْدٍ، قَالَ سَمِعْتُ زَيْدَ بْنَ ثَابِتٍ، فِي هَذَا الْمَكَانِ يَقُولُ أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ خَالِدًا فِيهَا ‏\}‏ بَعْدَ الَّتِي فِي الْفُرْقَانِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ بِسِتَّةِ أَشْهُرٍ ‏.‏\hadithno{4272}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zayd ibn Thabit: The verse "If a man kills a believer intentionally, his recompense is Hell to abide therein for ever" was revealed six months after the verse "And those who invoke not with Allah any other god, nor slay such life as Allah has made sacred, except for just cause in Surat al-Furqan}}
\hadithdefcmd{abudawud}{4273}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَوْ حَدَّثَنِي الْحَكَمُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ لَمَّا نَزَلَتِ الَّتِي فِي الْفُرْقَانِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ قَالَ مُشْرِكُو أَهْلِ مَكَّةَ قَدْ قَتَلْنَا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ وَدَعَوْنَا مَعَ اللَّهِ إِلَهًا آخَرَ وَأَتَيْنَا الْفَوَاحِشَ ‏.‏ فَأَنْزَلَ اللَّهُ ‏\{‏ إِلاَّ مَنْ تَابَ وَآمَنَ وَعَمِلَ عَمَلاً صَالِحًا فَأُولَئِكَ يُبَدِّلُ اللَّهُ سَيِّئَاتِهِمْ حَسَنَاتٍ ‏\}‏ فَهَذِهِ لأُولَئِكَ قَالَ وَأَمَّا الَّتِي فِي النِّسَاءِ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ ‏\}‏ الآيَةُ قَالَ الرَّجُلُ إِذَا عَرَفَ شَرَائِعَ الإِسْلاَمِ ثُمَّ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ لاَ تَوْبَةَ لَهُ ‏.‏ فَذَكَرْتُ هَذَا لِمُجَاهِدٍ فَقَالَ إِلاَّ مَنْ نَدِمَ ‏.‏\hadithno{4273}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3855) Sahih Muslim (3023)}\hadithtrans{Sa'id bin Jubair said:I asked Ibn 'Abbas (about the verse relating to intentional homicide in Surat An-Nisa') He said: When the verse "Those who invoke not with Allah any other god, nor slay such life as Allah had made sacred, except for just cause" was revealed, the polytheists of Mecca said: We have killed the soul prohibited by Allah, invoked another god along with Allah for worship, and committed shameful deeds. So Allah revealed the verse "unless he repents, believes, and works righteous deeds, for Allah will change the evil of such persons into good." This is meant for them. As regards the verse "if a man kills a believer intentionally, his recompense is Hell" He said: If a man knows the command of Islam and intentionally kills a believer, his repentance wil not be accepted. I then mentioned it to Mujahid. He said: "Except the one who is ashamed (of his sin)}}
\hadithdefcmd{abudawud}{4274}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي يَعْلَى، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي هَذِهِ الْقِصَّةِ فِي ‏\{‏ الَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ ‏\}‏ أَهْلُ الشِّرْكِ قَالَ وَنَزَلَ ‏\{‏ يَا عِبَادِيَ الَّذِينَ أَسْرَفُوا عَلَى أَنْفُسِهِمْ ‏\}‏ ‏.‏\hadithno{4274}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4810) Sahih Muslim (122)}\hadithtrans{The tradition mentioned above has also been transmitted by Sa'id b. Jubair from Ibn 'Abbas through a different chain of narrators. Ibn 'Abbas said:The verse: "Those who invoke not with Allah" applied to polytheists. He said: About them another verse, "Say: O my servants who have transgressed against their souls" was also revealed}}
\hadithdefcmd{abudawud}{4275}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا ‏\}‏ قَالَ مَا نَسَخَهَا شَىْءٌ ‏.‏\hadithno{4275}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4763، 4810) Sahih Muslim (122)}\hadithtrans{Ibn 'Abbas said:No other verse has repealed the verse "If a man kills a believer intentionally}}
\hadithdefcmd{abudawud}{4276}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي مِجْلَزٍ، فِي قَوْلِهِ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ ‏\}‏ قَالَ هِيَ جَزَاؤُهُ فَإِنْ شَاءَ اللَّهُ أَنْ يَتَجَاوَزَ عَنْهُ فَعَلَ ‏.‏\hadithno{4276}\hadithgrade{Al-Albani: Hasan Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Maqtu; Zubair Ali Zai: Daif}\hadithtrans{About the verse "If a man kills a believer intentionally" Abu Mijlaz said:This is his recompense. If Allah wishes to disregard him, He may do do}}
\hadithdefcmd{abudawud}{4277}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، سَلاَّمُ بْنُ سُلَيْمٍ عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ فِتْنَةً فَعَظَّمَ أَمْرَهَا فَقُلْنَا أَوْ قَالُوا يَا رَسُولَ اللَّهِ لَئِنْ أَدْرَكَتْنَا هَذِهِ لَتُهْلِكَنَّا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَلاَّ إِنَّ بِحَسْبِكُمُ الْقَتْلُ ‏"‏ ‏.‏ قَالَ سَعِيدٌ فَرَأَيْتُ إِخْوَانِي قُتِلُوا ‏.‏\hadithno{4277}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sa'id ibn Zayd: We were with the Prophet (ﷺ). He mentioned civil strife (fitnah) and expressed its gravity. We or the people said: Messenger of Allah, if this happens to us it will destroy us. The Messenger of Allah (ﷺ) said; No. It is enough for you that you would be killed. Sa'id said: I saw that my brethren were killed}}
\hadithdefcmd{abudawud}{4278}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمَّتِي هَذِهِ أُمَّةٌ مَرْحُومَةٌ لَيْسَ عَلَيْهَا عَذَابٌ فِي الآخِرَةِ عَذَابُهَا فِي الدُّنْيَا الْفِتَنُ وَالزَّلاَزِلُ وَالْقَتْلُ ‏"‏ ‏.‏\hadithno{4278}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuMusa: The Prophet (ﷺ) said: This people of mine is one to which mercy is shown. It will have no punishment in the next world, but its punishment in this world will be trials, earthquakes and being killed}}
